@@ -810,7 +810,7 @@ gpa_paper_preview_item_connect (GpaPaperPreviewItem *pp)
 		GNOME_PRINT_KEY_PAPER_HEIGHT,
 		GNOME_PRINT_KEY_PAPER_ORIENTATION,
 		GNOME_PRINT_KEY_PAGE_ORIENTATION,
-		GNOME_PRINT_KEY_LAYOUT,
+		GNOME_PRINT_KEY_LAYOUT
 	};
 	gint i, max;
 	
